/*------------------------------------------------------------------------------
watchdog.c : Sample Program that demonstrates the pulse width modulator for the
following microcontrollers

Infineon C505-2R
Infineon C505-L
Infineon C505C-2R
Infineon C505C-L
Infineon C505L-4E
Infineon C508

Copyright (c) 1988-2001 Keil Elektronik GmbH and Keil Software, Inc.
All rights reserved.
--------------------------------------------------------------------------*/

#include <stdio.h>


sfr   IEN0   = 0xA8; /* Bit-addressable SFR */
sfr   IEN1   = 0xB8; /* Bit-addressable SFR */
sfr   IP0    = 0xA9;
sfr   WDTREL = 0x86;

sfr   SCON   = 0x98; /* Bit-addressable SFR */
sfr   TMOD   = 0x89;
sfr   TH1    = 0x8D;
sbit  TR1   = 0x8E;
sbit  TI    = 0x99;

void refresh_Watchdog( void )
{
  IEN0 |= 0x40;
  IEN1 |= 0x40;  
}

void main( void )
{

  int i;  
 
  /*------------------------------------------------
	Setup the serial port for 1200 baud at 16MHz.
	------------------------------------------------*/
    SCON  = 0x50;		        /* SCON: mode 1, 8-bit UART, enable rcvr      */
    TMOD |= 0x20;               /* TMOD: timer 1, mode 2, 8-bit reload        */
    TH1   = 221;                /* TH1:  reload value for 1200 baud @ 16MHz   */
    TR1   = 1;                  /* TR1:  timer 1 run                          */
    TI    = 1;                  /* TI:   set TI to send first char of UART    */
  
  
  
  
  //Checking reset bit to determine if Watchdog Reset occured.	
  if( IP0 & 0x40 )
  {
    printf("Watchdog Reset Occured\n");
	IP0 |= ~0x40;
  }
  
  //Setting the time to maximum count time.
  WDTREL |= 0x80;
  refresh_Watchdog();

  //Testing to ensure that the watchdog doesn't reset
  for( i = 0; i < 5000; i++)
  {
    refresh_Watchdog();
  }

  //Loops to simulate a software error that would provoke a watchdog reset
  while(1);
  
}
